@@ -1338,205 +1338,5 @@ class emailmgmt {
         
         return ['status' => '1', 'msg' => 'Failed to create DKIM records after maximum retries'];
     }
-    
-    /**
-     * Import existing email accounts from mail server for a specific domain
-     * Only available to root users
-     */
-    public function importEmailAccountsFromDomain($domain_name, $target_username = null) {
-        if (!$this->db || !$this->mail_client) {
-            return ['status' => '1', 'msg' => 'Database or mail server connection failed'];
-        }
-        
-        try {
-            // Get all email accounts from mail server
-            $mail_accounts = $this->mail_client->listEmailAccounts();
-            
-            if (!$mail_accounts || !is_array($mail_accounts)) {
-                return ['status' => '1', 'msg' => 'Failed to retrieve accounts from mail server'];
-            }
-            
-            $imported_count = 0;
-            $skipped_count = 0;
-            $errors = [];
-            
-            foreach ($mail_accounts as $account) {
-                // Check if this account belongs to the specified domain
-                if (!isset($account['address']) || !str_ends_with($account['address'], '@' . $domain_name)) {
-                    continue;
-                }
-                
-                $email_address = $account['address'];
-                
-                // Check if account already exists in our database
-                $stmt = $this->db->prepare("SELECT id FROM whp.email_accounts WHERE email_address = ?");
-                $stmt->execute([$email_address]);
-                if ($stmt->fetch()) {
-                    $skipped_count++;
-                    continue;
-                }
-                
-                // Determine username - use target_username if provided, otherwise extract from email
-                $username = $target_username;
-                if (!$username) {
-                    $local_part = explode('@', $email_address)[0];
-                    $username = $local_part; // Default to email local part
-                }
-                
-                // Extract quota (default to 100MB if not available)
-                $quota_mb = isset($account['quota']) ? intval($account['quota'] / (1024 * 1024)) : 100;
-                
-                // Extract active status
-                $active = isset($account['active']) ? (bool)$account['active'] : true;
-                
-                // Import account to database (password will need to be reset)
-                $stmt = $this->db->prepare("
-                    INSERT INTO whp.email_accounts (email_address, username, domain_name, password_hash, quota_mb, active)
-                    VALUES (?, ?, ?, ?, ?, ?)
-                ");
-                
-                $password_hash = '[IMPORTED - RESET REQUIRED]'; // Placeholder since we can't get original password
-                
-                if ($stmt->execute([$email_address, $username, $domain_name, $password_hash, $quota_mb, $active])) {
-                    $imported_count++;
-                } else {
-                    $errors[] = "Failed to import $email_address";
-                }
-            }
-            
-            $message = "Import completed: $imported_count accounts imported, $skipped_count already existed.";
-            if (!empty($errors)) {
-                $message .= " Errors: " . implode(', ', $errors);
-            }
-            if ($imported_count > 0) {
-                $message .= " Note: Imported accounts require password reset.";
-            }
-            
-            return [
-                'status' => '0', 
-                'msg' => $message, 
-                'imported' => $imported_count, 
-                'skipped' => $skipped_count,
-                'errors' => $errors
-            ];
-            
-        } catch (Exception $e) {
-            error_log("Failed to import email accounts: " . $e->getMessage());
-            return ['status' => '1', 'msg' => 'Failed to import email accounts: ' . $e->getMessage()];
-        }
-    }
-    
-    /**
-     * Import existing email forwarders from mail server for a specific domain
-     * Only available to root users
-     */
-    public function importEmailForwardersFromDomain($domain_name, $target_username = null) {
-        if (!$this->db || !$this->mail_client) {
-            return ['status' => '1', 'msg' => 'Database or mail server connection failed'];
-        }
-        
-        try {
-            // Get all email aliases/forwarders from mail server
-            $mail_aliases = $this->mail_client->listEmailAliases();
-            
-            if (!$mail_aliases || !is_array($mail_aliases)) {
-                return ['status' => '1', 'msg' => 'Failed to retrieve forwarders from mail server'];
-            }
-            
-            $imported_count = 0;
-            $skipped_count = 0;
-            $errors = [];
-            
-            foreach ($mail_aliases as $alias) {
-                // Check if this alias/forwarder belongs to the specified domain
-                if (!isset($alias['address']) || !str_ends_with($alias['address'], '@' . $domain_name)) {
-                    continue;
-                }
-                
-                $source_email = $alias['address'];
-                
-                // Check if this has forwards (indicating it's a forwarder, not just an alias)
-                if (!isset($alias['forwardsTo']) || !is_array($alias['forwardsTo']) || empty($alias['forwardsTo'])) {
-                    continue;
-                }
-                
-                // Determine username
-                $username = $target_username;
-                if (!$username) {
-                    $local_part = explode('@', $source_email)[0];
-                    $username = $local_part;
-                }
-                
-                // Import each forwarding destination
-                foreach ($alias['forwardsTo'] as $destination_email) {
-                    // Check if forwarder already exists
-                    $stmt = $this->db->prepare("
-                        SELECT id FROM whp.email_forwarders 
-                        WHERE source_email = ? AND destination_email = ?
-                    ");
-                    $stmt->execute([$source_email, $destination_email]);
-                    if ($stmt->fetch()) {
-                        $skipped_count++;
-                        continue;
-                    }
-                    
-                    // Import forwarder to database
-                    $stmt = $this->db->prepare("
-                        INSERT INTO whp.email_forwarders (source_email, destination_email, username, active)
-                        VALUES (?, ?, ?, ?)
-                    ");
-                    
-                    $active = isset($alias['active']) ? (bool)$alias['active'] : true;
-                    
-                    if ($stmt->execute([$source_email, $destination_email, $username, $active])) {
-                        $imported_count++;
-                    } else {
-                        $errors[] = "Failed to import forwarder $source_email -> $destination_email";
-                    }
-                }
-            }
-            
-            $message = "Import completed: $imported_count forwarders imported, $skipped_count already existed.";
-            if (!empty($errors)) {
-                $message .= " Errors: " . implode(', ', $errors);
-            }
-            
-            return [
-                'status' => '0', 
-                'msg' => $message, 
-                'imported' => $imported_count, 
-                'skipped' => $skipped_count,
-                'errors' => $errors
-            ];
-            
-        } catch (Exception $e) {
-            error_log("Failed to import email forwarders: " . $e->getMessage());
-            return ['status' => '1', 'msg' => 'Failed to import email forwarders: ' . $e->getMessage()];
-        }
-    }
-    
-    /**
-     * Get list of domains from mail server that can be imported
-     * Only available to root users
-     */
-    public function getImportableDomains() {
-        if (!$this->mail_client) {
-            return ['status' => '1', 'msg' => 'Mail server connection failed'];
-        }
-        
-        try {
-            $domains = $this->mail_client->listDomains();
-            
-            if (!$domains || !is_array($domains)) {
-                return ['status' => '1', 'msg' => 'Failed to retrieve domains from mail server'];
-            }
-            
-            return ['status' => '0', 'domains' => $domains];
-            
-        } catch (Exception $e) {
-            error_log("Failed to get importable domains: " . $e->getMessage());
-            return ['status' => '1', 'msg' => 'Failed to retrieve domains: ' . $e->getMessage()];
-        }
-    }
 }
 ?> 
\ No newline at end of file
